pub struct QuantizationParametersPrimitive<B: Backend> {
pub scales: B::FloatTensorPrimitive,
pub global: Option<B::FloatTensorPrimitive>,
}Expand description
The quantization parameters primitive.
Remarks
This is a low-level struct used internally by the library to provide the quantization parameters to the backends. It is not designed for direct usage by users, and not recommended to import or use this struct directly.
Fields
scales: B::FloatTensorPrimitiveThe scaling factor, one per block or a single one for a per-tensor level, in the quantized tensor’s float dtype.
global: Option<B::FloatTensorPrimitive>The per-tensor scale that scales are expressed relative to, for a
two-level scheme. Always f32, unlike scales, so the two cannot go into a binary op
without a cast.