TransactionOp

Trait TransactionOp 

pub trait TransactionOp<B: Backend>: TensorKind<B> {
    // Required method
    fn register_transaction(
        tr: &mut TransactionPrimitive<B>,
        tensor: Self::Primitive,
    );
}
Trait for the one basic op that still requires Backend

Warnings

This is an internal trait, use the public API provided by the Tensor

Required Methods

fn register_transaction( tr: &mut TransactionPrimitive<B>, tensor: Self::Primitive, )

Read the data from the tensor using a transaction.

Remarks

This is a low-level function used internally by the library to call different backend functions with static dispatch. It is not designed for direct usage by users, and not recommended to import or use this function directly.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors