pub trait FloatMathOps<B: Backend>: Numeric<B> {
Show 18 methods
// Required methods
fn square(tensor: Self::Primitive) -> Self::Primitive;
fn exp(tensor: Self::Primitive) -> Self::Primitive;
fn log1p(tensor: Self::Primitive) -> Self::Primitive;
fn log(tensor: Self::Primitive) -> Self::Primitive;
fn sqrt(tensor: Self::Primitive) -> Self::Primitive;
fn cos(tensor: Self::Primitive) -> Self::Primitive;
fn sin(tensor: Self::Primitive) -> Self::Primitive;
fn tan(tensor: Self::Primitive) -> Self::Primitive;
fn cosh(tensor: Self::Primitive) -> Self::Primitive;
fn sinh(tensor: Self::Primitive) -> Self::Primitive;
fn tanh(tensor: Self::Primitive) -> Self::Primitive;
fn acos(tensor: Self::Primitive) -> Self::Primitive;
fn acosh(tensor: Self::Primitive) -> Self::Primitive;
fn asin(tensor: Self::Primitive) -> Self::Primitive;
fn asinh(tensor: Self::Primitive) -> Self::Primitive;
fn atan(tensor: Self::Primitive) -> Self::Primitive;
fn atanh(tensor: Self::Primitive) -> Self::Primitive;
fn atan2(lhs: Self::Primitive, rhs: Self::Primitive) -> Self::Primitive;
}Expand description
Required Methods
Sourcefn square(tensor: Self::Primitive) -> Self::Primitive
fn square(tensor: Self::Primitive) -> Self::Primitive
Applies element wise square operation
$y_i = x^{2}$
Sourcefn exp(tensor: Self::Primitive) -> Self::Primitive
fn exp(tensor: Self::Primitive) -> Self::Primitive
Applies element wise exponential operation.
$y_i = e^{x_i}$
Sourcefn log1p(tensor: Self::Primitive) -> Self::Primitive
fn log1p(tensor: Self::Primitive) -> Self::Primitive
Applies the natural logarithm of one plus the input tensor, element-wise.
$y_i = \log_e(x_i + 1)$
Sourcefn log(tensor: Self::Primitive) -> Self::Primitive
fn log(tensor: Self::Primitive) -> Self::Primitive
Applies element wise natural log operation ln.
$y_i = \log_e(x_i)$
Sourcefn sqrt(tensor: Self::Primitive) -> Self::Primitive
fn sqrt(tensor: Self::Primitive) -> Self::Primitive
Applies element wise root square operation.
$y_i = \sqrt{x_i}$
Sourcefn cos(tensor: Self::Primitive) -> Self::Primitive
fn cos(tensor: Self::Primitive) -> Self::Primitive
Returns a new tensor with cosine values.
Arguments
tensor- The input tensor.
Returns
A tensor with the same shape as tensor with cosine values.
Remarks
This is a low-level function used internally by the library to call different backend functions with static dispatch. It is not designed for direct usage by users, and not recommended to import or use this function directly.
For the cosine of a tensor, users should prefer the
Tensor::cos
function, which is more high-level and designed for public use.
Sourcefn sin(tensor: Self::Primitive) -> Self::Primitive
fn sin(tensor: Self::Primitive) -> Self::Primitive
Returns a new tensor with sine values.
Arguments
tensor- The input tensor.
Returns
A tensor with the same shape as tensor with sine values.
Remarks
This is a low-level function used internally by the library to call different backend functions with static dispatch. It is not designed for direct usage by users, and not recommended to import or use this function directly.
For the sine of a tensor, users should prefer the
Tensor::sin
function, which is more high-level and designed for public use.
Sourcefn tan(tensor: Self::Primitive) -> Self::Primitive
fn tan(tensor: Self::Primitive) -> Self::Primitive
Returns a new tensor with tangent values.
Arguments
tensor- The input tensor.
Returns
A tensor with the same shape as tensor with tangent values.
Remarks
This is a low-level function used internally by the library to call different backend functions with static dispatch. It is not designed for direct usage by users, and not recommended to import or use this function directly.
For the tangent of a tensor, users should prefer the
Tensor::tan
function, which is more high-level and designed for public use.
Sourcefn cosh(tensor: Self::Primitive) -> Self::Primitive
fn cosh(tensor: Self::Primitive) -> Self::Primitive
Returns a new tensor with hyperbolic cosine values.
Arguments
tensor- The input tensor.
Returns
A tensor with the same shape as tensor with hyperbolic cosine values.
Remarks
This is a low-level function used internally by the library to call different backend functions with static dispatch. It is not designed for direct usage by users, and not recommended to import or use this function directly.
For the hyperbolic cosine of a tensor, users should prefer the
Tensor::cosh
function, which is more high-level and designed for public use.
Sourcefn sinh(tensor: Self::Primitive) -> Self::Primitive
fn sinh(tensor: Self::Primitive) -> Self::Primitive
Returns a new tensor with hyperbolic sine values.
Arguments
tensor- The input tensor.
Returns
A tensor with the same shape as tensor with hyperbolic sine values.
Remarks
This is a low-level function used internally by the library to call different backend functions with static dispatch. It is not designed for direct usage by users, and not recommended to import or use this function directly.
For the hyperbolic sine of a tensor, users should prefer the
Tensor::sinh
function, which is more high-level and designed for public use.
Sourcefn tanh(tensor: Self::Primitive) -> Self::Primitive
fn tanh(tensor: Self::Primitive) -> Self::Primitive
Returns a new tensor with hyperbolic tangent values.
Arguments
tensor- The input tensor.
Returns
A tensor with the same shape as tensor with hyperbolic tangent values.
Remarks
This is a low-level function used internally by the library to call different backend functions with static dispatch. It is not designed for direct usage by users, and not recommended to import or use this function directly.
For the hyperbolic tangent of a tensor, users should prefer the
Tensor::tanh
function, which is more high-level and designed for public use.
Sourcefn acos(tensor: Self::Primitive) -> Self::Primitive
fn acos(tensor: Self::Primitive) -> Self::Primitive
Returns a new tensor with inverse cosine values.
Arguments
tensor- The input tensor.
Returns
A tensor with the same shape as tensor with inverse cosine values.
Remarks
This is a low-level function used internally by the library to call different backend functions with static dispatch. It is not designed for direct usage by users, and not recommended to import or use this function directly.
For the inverse cosine of a tensor, users should prefer the
Tensor::acos
function, which is more high-level and designed for public use.
Sourcefn acosh(tensor: Self::Primitive) -> Self::Primitive
fn acosh(tensor: Self::Primitive) -> Self::Primitive
Returns a new tensor with inverse hyperbolic cosine values.
Arguments
tensor- The input tensor.
Returns
A tensor with the same shape as tensor with inverse hyperbolic cosine values.
Remarks
This is a low-level function used internally by the library to call different backend functions with static dispatch. It is not designed for direct usage by users, and not recommended to import or use this function directly.
For the inverse hyperbolic cosine of a tensor, users should prefer the
Tensor::acosh
function, which is more high-level and designed for public use.
Sourcefn asin(tensor: Self::Primitive) -> Self::Primitive
fn asin(tensor: Self::Primitive) -> Self::Primitive
Returns a new tensor with inverse sine values.
Arguments
tensor- The input tensor.
Returns
A tensor with the same shape as tensor with inverse sine values.
Remarks
This is a low-level function used internally by the library to call different backend functions with static dispatch. It is not designed for direct usage by users, and not recommended to import or use this function directly.
For the inverse sine of a tensor, users should prefer the
Tensor::asin
function, which is more high-level and designed for public use.
Sourcefn asinh(tensor: Self::Primitive) -> Self::Primitive
fn asinh(tensor: Self::Primitive) -> Self::Primitive
Returns a new tensor with inverse hyperbolic sine values.
Arguments
tensor- The input tensor.
Returns
A tensor with the same shape as tensor with inverse hyperbolic sine values.
Remarks
This is a low-level function used internally by the library to call different backend functions with static dispatch. It is not designed for direct usage by users, and not recommended to import or use this function directly.
For the inverse hyperbolic sine of a tensor, users should prefer the
Tensor::asinh
function, which is more high-level and designed for public use.
Sourcefn atan(tensor: Self::Primitive) -> Self::Primitive
fn atan(tensor: Self::Primitive) -> Self::Primitive
Returns a new tensor with inverse tangent values.
Arguments
tensor- The input tensor.
Returns
A tensor with the same shape as tensor with inverse tangent values.
Remarks
This is a low-level function used internally by the library to call different backend functions with static dispatch. It is not designed for direct usage by users, and not recommended to import or use this function directly.
For the inverse tangent of a tensor, users should prefer the
Tensor::atan
function, which is more high-level and designed for public use.
Sourcefn atanh(tensor: Self::Primitive) -> Self::Primitive
fn atanh(tensor: Self::Primitive) -> Self::Primitive
Returns a new tensor with inverse hyperbolic tangent values.
Arguments
tensor- The input tensor.
Returns
A tensor with the same shape as tensor with inverse hyperbolic tangent values.
Remarks
This is a low-level function used internally by the library to call different backend functions with static dispatch. It is not designed for direct usage by users, and not recommended to import or use this function directly.
For the inverse hyperbolic tangent of a tensor, users should prefer the
Tensor::atanh
function, which is more high-level and designed for public use.
Sourcefn atan2(lhs: Self::Primitive, rhs: Self::Primitive) -> Self::Primitive
fn atan2(lhs: Self::Primitive, rhs: Self::Primitive) -> Self::Primitive
Returns a tensor with the four-quadrant inverse tangent values of y and x.
Arguments
lhs- The tensor with y coordinates.rhs- The tensor with x coordinates.
Returns
A tensor with the four-quadrant inverse tangent values.
Remarks
This is a low-level function used internally by the library to call different backend functions with static dispatch. It is not designed for direct usage by users, and not recommended to import or use this function directly.
For the four-quadrant inverse tangent of two tensors, users should prefer the
Tensor::atan2
function, which is more high-level and designed for public use.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.